@@ -46,7 +46,6 @@ __all__ = """
 """.split()
 
 import re, sys
-from copy import deepcopy
 from pyoverload.utils import decorator, get_environ_vars
 
 try:
@@ -324,14 +323,16 @@ class _strIO:
 
 def _getDeclaration(func):
     if have_inspect and '__file__' in func.__globals__:
-        dec = next(l for l in inspect.getsource(func).split('\n') if l.strip() and not l.strip().startswith('@')).strip().rstrip(':')
-    else:
-        ss = _strIO()
-        oldout = sys.stdout
-        sys.stdout = ss
-        help(func)
-        sys.stdout = oldout
-        dec = [l for l in ss.split('\n') if len(l) > 0 and 'Help' not in l][0].replace("def ", '').strip().strip(':')
+        try:
+            dec = next(l for l in inspect.getsource(func).split('\n') if l.strip() and not l.strip().startswith('@')).strip().rstrip(':')
+            return dec[dec.index('('):]
+        except OSError: pass
+    ss = _strIO()
+    oldout = sys.stdout
+    sys.stdout = ss
+    help(func)
+    sys.stdout = oldout
+    dec = [l for l in ss.split('\n') if len(l) > 0 and 'Help' not in l][0].replace("def ", '').strip().strip(':')
     return dec[dec.index('('):]
 
 def _get_func_name(f):
@@ -380,15 +381,27 @@ class Type(type):
         return output
 
     def __new__(cls, *_T, name=None, shape=tuple(), inv=False, ext=False, itypes=None):
-        _T = Type.extractType(_T)
+        if len(_T) == 1 and isinstance(_T[0], Type):
+            inv = _T[0].inv
+            name = _T[0].name
+            shape = _T[0].shape
+            ext = _T[0].extendable
+            itypes = _T[0].itemtypes
+            inheritableT = _T[0].inheritableT
+            _T = _T[0].types
+        else:
+            _T = Type.extractType(_T)
+            if name == None: name = cls.__name__ + '.' + '/'.join(map(typename, _T))
+            inheritableT = tuple(t for t in _T if inheritable(t))
 
-        self = super().__new__(cls, cls.__name__ + '.' + '/'.join(map(typename, _T)), tuple(t for t in _T if inheritable(t)), {})
+        self = super().__new__(cls, name, inheritableT, {})
         self.inv = inv
         self.types = _T
         self.name = name
         self.shape = shape
         self.extendable = ext
         self.itemtypes = itypes
+        self.inheritableT = inheritableT
         return self
 
     def __init__(*args, **kwargs): pass
@@ -406,11 +419,11 @@ class Type(type):
                 if all([isinstance(x, slice) for x in i]): return self@{x.start:x.stop for x in i}
                 if all([isinstance(x, str) or isatype(x) for x in i]): return self@Type(*i)
                 raise TypeHintError("Wrong size specifier. ")
-            T = deepcopy(self)
+            T = Type(self)
             T.shape = i
             return T
         else:
-            T = deepcopy(self)
+            T = Type(self)
             T.types = sequence
             T.name = "Iterable"
             T.shape = i
@@ -437,7 +450,7 @@ class Type(type):
         if other is None: return
         if not all(isitertype(x) for x in self.types): raise TypeError("Only iterable Type can use @ to specify the items. ")
         if isinstance(other, Type) or all(isarray(x) for x in self.types) and isdtype(other):
-            T = deepcopy(self)
+            T = Type(self)
             T.itemtypes = other
             return T
         shape = self.shape
@@ -445,17 +458,17 @@ class Type(type):
         if not iterable(other): other = (other,)
         if len(shape) == 1 and len(other) not in (1, shape[0]): raise TypeHintError("Wrong number of item types for @. ")
         if isinstance(other, dict) and not all([isofsubclass(x, dict) for x in self.types]): raise TypeHintError("Please do use {a:b} typehint for dicts.")
-        T = deepcopy(self)
+        T = Type(self)
         T.itemtypes = other
         return T
 
     def __pos__(self):
-        T = deepcopy(self)
+        T = Type(self)
         T.extendable = True
         return T
 
     def __invert__(self):
-        T = deepcopy(self)
+        T = Type(self)
         T.inv = not self.inv
         return T
 
